#!/usr/bin/env python3
"""
invoke with the path to a meas.csv file for the stacked_core 39-xx demos
to extract higher-level info from them.
"""
import os
import sys
import re

from stacked_cores import load_csv, labeled_rows, last_row_before_t, extract_m

def extract_one(path: str, t_first: float, t_last: float):
    header, raw_rows = load_csv(path)
    rows = labeled_rows(header, raw_rows)

    tx_init = last_row_before_t(rows, t_first)
    tx_fini = last_row_before_t(rows, t_last)
    m_init = extract_m(tx_init)
    m_fini = extract_m(tx_fini)

    return m_init[0], m_fini[-1]

def extract_polarity(stem: str) -> float:
    s = None
    if re.search("-p\d\d\d", stem):
        s = re.search("-p\d\d\d", stem).group(0)
    if re.search("-n\d\d\d", stem):
        s = re.search("-n\d\d\d", stem).group(0)

    if s:
        sign = {'n': -1, 'p': 1}[s[1]]
        mag = int(s[2:])
        return sign * mag * 0.01

    if "-000" in stem:
        return 0.00

def extract_39xx(base_path: str, t_first: str = "2e-9", t_last: str = "3e-9"):
    base_dir, prefix = os.path.split(base_path)
    mappings = {}
    for entry in os.listdir(base_dir):
        if entry.startswith(prefix):
            (input_, output) = extract_one(os.path.join(base_dir, entry, "meas.csv"), float(t_first), float(t_last))
            polarity = extract_polarity(entry)
            mappings[int(round(input_))] = (int(round(output)), polarity)

    print("Piecewise(")
    print("    [")
    for i, (o, polarity) in sorted(mappings.items()):
        comment = f"  # {polarity:.2}" if polarity is not None else ""
        print(f"        [ {i:6}, {o:6} ],{comment}")
    print("    ]")
    print(")")


if __name__ == '__main__':
    extract_39xx(*sys.argv[1:])
